.. _changelog:

*********
Changelog
*********

This is the changelog for Gammapy.
For now we use a one-line description of every pull request, roughly in chronological order.

We don't list every pull request.
Maintenance and cleanup changes (e.g. to update astropy-helpers or fix the docs build)
are not of interest to users and are not listed here.

A complete list of Gammapy contributors is at https://gammapy.org/team.html .

.. include:: ../CHANGES.rst
